@@ -4,7 +4,7 @@ import numpy as np
 import wget
 import gzip
 import shutil
-from tqdm import tqdm
+import uuid
 import pandas as pd
 from concurrent.futures import ThreadPoolExecutor, as_completed
 
@@ -44,6 +44,9 @@ def lift_data(
     Notes:
         Function for the :meth:`Geno.lift` method.
     """
+    # Generate a default name if none is provided
+    if name is None:
+        name = str(uuid.uuid4())[:8]
 
     # Prepare chain file and get its path
     chain_path = prepare_chain_file(chain_file, start, end)
